import { IfNever } from 'type-fest';
import { I as IterableContainer, T as TupleParts, N as NTuple } from './types-CHlN5MFk.js';

type Drop<T extends IterableContainer, N extends number> = number extends N ? Array<T[number]> : `${N}` extends `-${number}` ? T : [
    ...(TupleParts<T>["prefix"] extends [...NTuple<unknown, N>, ...infer V] ? V : []),
    ...IfNever<TupleParts<T>["item"], [
    ], Array<TupleParts<T>["item"] | TupleParts<T>["suffix"][number]>>
];
/**
 * Removes first `n` elements from the `array`.
 *
 * @param array - The target array.
 * @param n - The number of elements to skip.
 * @signature
 *    R.drop(array, n)
 * @example
 *    R.drop([1, 2, 3, 4, 5], 2) // => [3, 4, 5]
 * @dataFirst
 * @lazy
 * @category Array
 */
declare function drop<T extends IterableContainer, N extends number>(array: T, n: N): Drop<T, N>;
/**
 * Removes first `n` elements from the `array`.
 *
 * @param n - The number of elements to skip.
 * @signature
 *    R.drop(n)(array)
 * @example
 *    R.drop(2)([1, 2, 3, 4, 5]) // => [3, 4, 5]
 * @dataLast
 * @lazy
 * @category Array
 */
declare function drop<N extends number>(n: N): <T extends IterableContainer>(array: T) => Drop<T, N>;

export { drop };
